@@ -23,6 +23,7 @@
 #if !defined(__gda_data_model_h__)
 #  define __gda_data_model_h__
 
+#include <glib-object.h>
 #include <libgda/gda-row.h>
 #include <libgda/gda-value.h>
 
@@ -67,7 +68,11 @@ gint                gda_data_model_get_n_columns (GdaDataModel *model);
 GdaFieldAttributes *gda_data_model_describe_column (GdaDataModel *model, gint col);
 const gchar        *gda_data_model_get_column_title (GdaDataModel *model, gint col);
 void                gda_data_model_set_column_title (GdaDataModel *model, gint col, const gchar *title);
-const GdaValue *gda_data_model_get_value_at (GdaDataModel *model, gint col, gint row);
+const GdaValue     *gda_data_model_get_value_at (GdaDataModel *model, gint col, gint row);
+
+gchar              *gda_data_model_to_comma_separated (GdaDataModel *model);
+gchar              *gda_data_model_to_tab_separated (GdaDataModel *model);
+gchar              *gda_data_model_to_xml (GdaDataModel *model, gboolean standalone);
 
 G_END_DECLS
 
